==> nmrium-0.53.0.tgz: package/lib/component/panels/multipleAnalysisPanel/preferences/index.js <==
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Formik } from 'formik';
import { AnalysisColumnsTypes, } from 'nmr-load-save';
import { forwardRef, useImperativeHandle, useRef } from 'react';
import * as Yup from 'yup';
import { usePreferences } from '../../../context/PreferencesContext';
import { GroupPane } from '../../../elements/GroupPane';
import Label from '../../../elements/Label';
import FormikCheckBox from '../../../elements/formik/FormikCheckBox';
import useCheckExperimentalFeature from '../../../hooks/useCheckExperimentalFeature';
import { usePanelPreferences } from '../../../hooks/usePanelPreferences';
import { PreferencesContainer } from '../../extra/preferences/PreferencesContainer';
import { AnalysisTablePreferences } from './AnalysisTablePreferences';
import LegendsPreferences from './LegendsPreferences';
import MultipleAnalysisCodeEditor from './MultipleAnalysisCodeEditor';
function getMultipleSpectraAnalysisData(preferences) {
    return Object.keys(preferences.analysisOptions.columns).map((key) => ({
        ...preferences.analysisOptions.columns[key],
        tempKey: key,
    }));
}
const preferencesSchema = Yup.object({
    analysisOptions: Yup.object({
        columns: Yup.lazy((data) => {
            return Yup.array().of(columnSchema(data));
        }),
    }),
    legendsFields: Yup.array().of(Yup.object({
        jpath: Yup.array().of(Yup.string()).min(1),
    })),
});
// TODO: remove this hacky use of ref.
function MultipleSpectraAnalysisPreferences({ data, activeTab, onAfterSave }, ref) {
    const refForm = useRef();
    const panelPreferences = usePanelPreferences('multipleSpectraAnalysis', activeTab);
    const preferences = usePreferences();
    const columns = getMultipleSpectraAnalysisData(panelPreferences);
    const isExperimental = useCheckExperimentalFeature();
    useImperativeHandle(ref, () => ({
        saveSetting() {
            refForm.current.submitForm();
        },
    }));
    function submitHandler(values) {
        onAfterSave?.(true);
        preferences.dispatch({
            type: 'SET_SPECTRA_ANALYSIS_PREFERENCES',
            payload: { data: values, nucleus: activeTab },
        });
    }
    return (_jsx(PreferencesContainer, { style: { backgroundColor: 'white' }, children: _jsx(Formik, { innerRef: refForm, initialValues: {
                ...panelPreferences,
                analysisOptions: { ...panelPreferences?.analysisOptions, columns },
            }, enableReinitialize: true, validationSchema: preferencesSchema, onSubmit: submitHandler, children: _jsxs(_Fragment, { children: [_jsx(GroupPane, { text: "Legends", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(LegendsPreferences, {}) }), _jsx(GroupPane, { text: "General", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(Label, { title: "Enable resort spectra", children: _jsx(FormikCheckBox, { name: "resortSpectra" }) }) }), _jsx(GroupPane, { text: "Columns Settings ", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(AnalysisTablePreferences, {}) }), isExperimental && (_jsx(GroupPane, { text: "Execute code ", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(MultipleAnalysisCodeEditor, { data: data }) }))] }) }) }));
}
function columnSchema(columns) {
    return Yup.object().shape({
        tempKey: Yup.string()
            .required()
            .test('unique', 'must be unique column name', function check(columnName) {
            const colsFrequency = {};
            let index = 0;
            for (const column of columns) {
                if (column.tempKey === columnName) {
                    if (colsFrequency[column.tempKey]) {
                        colsFrequency[column.tempKey].push(index);
                    }
                    else {
                        colsFrequency[column.tempKey] = [index];
                    }
                }
                index++;
            }
            const errors = [];
            for (const key in colsFrequency) {
                const indexes = colsFrequency[key];
                if (indexes.length > 1) {
                    errors.push(new Yup.ValidationError(`${key} nucleus must te be unique`, key, 
                    // eslint-disable-next-line no-invalid-this
                    this.path));
                }
            }
            return new Yup.ValidationError(errors);
        }),
        formula: Yup.string().test('required', 'Pease enter formula field', function checkRequired() {
            const errors = [];
            for (const column of columns) {
                if (column?.type === AnalysisColumnsTypes.FORMULA &&
                    (!column.formula || column.formula === '')) {
                    errors.push(new Yup.ValidationError(`${column.tempKey} formula value is required`, column.formula, 
                    // eslint-disable-next-line no-invalid-this
                    this.path));
                }
            }
            return new Yup.ValidationError(errors);
        }),
        index: Yup.string().required(),
    });
}
export default forwardRef(MultipleSpectraAnalysisPreferences);

==> nmrium-0.55.0.tgz: package/lib/component/panels/multipleAnalysisPanel/preferences/index.js <==
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Formik } from 'formik';
import { AnalysisColumnsTypes, } from 'nmr-load-save';
import { forwardRef, useImperativeHandle, useRef } from 'react';
import * as Yup from 'yup';
import { usePreferences } from '../../../context/PreferencesContext';
import { GroupPane } from '../../../elements/GroupPane';
import Label from '../../../elements/Label';
import FormikCheckBox from '../../../elements/formik/FormikCheckBox';
import useCheckExperimentalFeature from '../../../hooks/useCheckExperimentalFeature';
import { usePanelPreferences } from '../../../hooks/usePanelPreferences';
import { PreferencesContainer } from '../../extra/preferences/PreferencesContainer';
import { AnalysisTablePreferences } from './AnalysisTablePreferences';
import LegendsPreferences from './LegendsPreferences';
import MultipleAnalysisCodeEditor from './MultipleAnalysisCodeEditor';
function getMultipleSpectraAnalysisData(preferences) {
    return Object.keys(preferences.analysisOptions.columns).map((key) => ({
        ...preferences.analysisOptions.columns[key],
        tempKey: key,
    }));
}
const preferencesSchema = Yup.object({
    analysisOptions: Yup.object({
        columns: Yup.lazy((data) => {
            return Yup.array().of(columnSchema(data));
        }),
    }),
    legendsFields: Yup.array().of(Yup.object({
        jpath: Yup.array().of(Yup.string()).min(1),
    })),
});
// TODO: remove this hacky use of ref.
function MultipleSpectraAnalysisPreferences({ data, activeTab, onAfterSave }, ref) {
    const refForm = useRef();
    const panelPreferences = usePanelPreferences('multipleSpectraAnalysis', activeTab);
    const preferences = usePreferences();
    const columns = getMultipleSpectraAnalysisData(panelPreferences);
    const isExperimental = useCheckExperimentalFeature();
    useImperativeHandle(ref, () => ({
        saveSetting() {
            refForm.current.submitForm();
        },
    }));
    function submitHandler(values) {
        onAfterSave?.(true);
        preferences.dispatch({
            type: 'SET_SPECTRA_ANALYSIS_PREFERENCES',
            payload: { data: values, nucleus: activeTab },
        });
    }
    return (_jsx(PreferencesContainer, { style: { backgroundColor: 'white' }, children: _jsx(Formik, { innerRef: refForm, initialValues: {
                ...panelPreferences,
                analysisOptions: { ...panelPreferences?.analysisOptions, columns },
            }, enableReinitialize: true, validationSchema: preferencesSchema, onSubmit: submitHandler, children: _jsxs(_Fragment, { children: [_jsx(GroupPane, { text: "Legends", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(LegendsPreferences, {}) }), _jsx(GroupPane, { text: "General", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(Label, { title: "Sort spectra when sorting columns", children: _jsx(FormikCheckBox, { name: "analysisOptions.resortSpectra" }) }) }), _jsx(GroupPane, { text: "Columns Settings ", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(AnalysisTablePreferences, {}) }), isExperimental && (_jsx(GroupPane, { text: "Execute code ", style: {
                            header: { color: 'black' },
                            container: { padding: '5px' },
                        }, children: _jsx(MultipleAnalysisCodeEditor, { data: data }) }))] }) }) }));
}
function columnSchema(columns) {
    return Yup.object().shape({
        tempKey: Yup.string()
            .required()
            .test('unique', 'must be unique column name', function check(columnName) {
            const colsFrequency = {};
            let index = 0;
            for (const column of columns) {
                if (column.tempKey === columnName) {
                    if (colsFrequency[column.tempKey]) {
                        colsFrequency[column.tempKey].push(index);
                    }
                    else {
                        colsFrequency[column.tempKey] = [index];
                    }
                }
                index++;
            }
            const errors = [];
            for (const key in colsFrequency) {
                const indexes = colsFrequency[key];
                if (indexes.length > 1) {
                    errors.push(new Yup.ValidationError(`${key} nucleus must te be unique`, key, 
                    // eslint-disable-next-line no-invalid-this
                    this.path));
                }
            }
            return new Yup.ValidationError(errors);
        }),
        formula: Yup.string().test('required', 'Pease enter formula field', function checkRequired() {
            const errors = [];
            for (const column of columns) {
                if (column?.type === AnalysisColumnsTypes.FORMULA &&
                    (!column.formula || column.formula === '')) {
                    errors.push(new Yup.ValidationError(`${column.tempKey} formula value is required`, column.formula, 
                    // eslint-disable-next-line no-invalid-this
                    this.path));
                }
            }
            return new Yup.ValidationError(errors);
        }),
        index: Yup.string().required(),
    });
}
export default forwardRef(MultipleSpectraAnalysisPreferences);
